#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <sys/time.h>

#include <vector>

using namespace std;

double scale(double val, double dmin, double dmax, double nmin, double nmax)
{
    return ((val - dmin) / (dmax - dmin)) * (nmax - nmin) + nmin;
}

struct Pair
{
    double x, y;
    
    void cmp_peak(Pair& o)
    {
        if(o.y > y)
        {
            x = o.x;
            y = o.y;
        }
    }
};

struct Data : public vector<Pair>
{
    double min_x, max_x, min_y, max_y;
    
    void read(double limit = 0)
    {
        double tmp1, tmp2;

        while( scanf("%lf %lf", &tmp1, &tmp2) != EOF )
        {
            if(tmp2 > limit)
                push_back( (Pair){tmp1, tmp2} );
        }
        
        calc_bounds();
    }
    
    void scale_x(double nmin, double nmax)
    {
        for(size_t i = 0, e = size(); i < e; ++i)
            at(i).x = ::scale(at(i).x, min_x, max_x, nmin, nmax);
        
        min_x = nmin;
        max_x = nmax;
    }
    
    void scale_y(double nmin, double nmax)
    {
        for(size_t i = 0, e = size(); i < e; ++i)
            at(i).y = ::scale(at(i).y, min_y, max_y, nmin, nmax);
        
        min_y = nmin;
        max_y = nmax;
    }
    
    void calc_bounds()
    {
        min_x = min_y = 1e30;
        max_x = max_y = -1e30;
        
        for(size_t i = 0, e = size(); i < e; ++i)
        {
            if(at(i).x < min_x) min_x = at(i).x; else if(at(i).x > max_x) max_x = at(i).x;
            if(at(i).y < min_y) min_y = at(i).y; else if(at(i).y > max_y) max_y = at(i).y;
        }
    }
    
    void print()
    {
        for(size_t i = 0, e = size(); i < e; ++i)
            printf("%.12lf %.12lf\n", at(i).x, at(i).y);    
    }
};

unsigned int random_seed()
{
    unsigned int seed;
        
#ifndef _WIN32
    FILE* rf = fopen("/dev/urandom", "r");

    if(!rf)
    {
        struct timeval tv;
        gettimeofday(&tv, NULL);
        seed = tv.tv_usec + tv.tv_sec;
    }
    else
    {
        fread(&seed, sizeof(seed), 1, rf);
        fclose(rf);
    }
#else
    seed = time(NULL);
#endif
    return seed;
}

double rand_double(double max)
{
    return rand() / (RAND_MAX / max);
}
