/**
 * Peak determination by function approximation, using a FCC network.
 * 
 * Usage:
 * 
 * ./fcc plot limit < input_spectrum
 */

#include <supernn/supernn.hpp>
#include <cstdio>
#include <string.h>
#include "common.cpp"

int main(int argc, char* argv[])
{
    /* read program options */
    char plot = 0;
    double limit;
    if(argc >= 2) plot  = argv[1][0] == 'p';
    if(argc >= 3) limit = atof(argv[2]); else limit = 0.65;
    
    Data data;
    data.read(limit);
    
    SuperNN::Utils::rand_seed();
    
    SuperNN::Network net = SuperNN::Network::make_fcc(1, 1, 1);
    net.layers[1].set_activation(SuperNN::ACT_SIGMOID);
    net.layers[2].set_activation(SuperNN::ACT_LINEAR);
    net.init_weights(0.5, 1);
    
    SuperNN::NBN t;
    t.prepare(net);
    
    SuperNN::Data full(data.size(), 2);
    
    for(size_t i = 0, e = data.size(); i < e; ++i)
    {
        SuperNN::Row& row = full.add();
        row[0] = data[i].x;
        row[1] = data[i].y;
    }
    
    full.calc_bounds();
    full.scale(0, 1);
    
    t.train(net, full, 0, 50);
    
    double step_size = 1e-4;
    int n_steps      = (data.max_x - data.min_x) / step_size, i;
    
    SuperNN::Data in(1, 2);
    in.from = full.from;
    SuperNN::Row& r = in.add();
    Pair peak = {-1, -1}, cur;
    
    for(i = 0; i <= n_steps; ++i)
    {
        cur.x = data.min_x + i * step_size;
        r[0] = cur.x;
        in.scale(0, 1);
        SuperNN::Row& o = net.run(r);
        r[1] = o[0];
        in.descale();
        
        cur.y = r[1];
        peak.cmp_peak(cur);
        if(plot) printf("%.12lf %.12lf\n", cur.x, cur.y);
    }
        
    if(!plot) printf("%lf\n", peak.x);
    
    return 0;
}
