#!/usr/bin/env lua

--[[
    Script that generates the datasets with different noise levels.

    Usage:

    ./gen_data profile wave_len
--]]

-- noise amplitude needed for each dB level
local vals_uniform = {
    [60] = 0.0010,
    [58] = 0.0013,
    [56] = 0.0016,
    [54] = 0.0020,
    [52] = 0.00255,
    [50] = 0.0033,
    [48] = 0.004,
    [46] = 0.005,
    [44] = 0.0062,
    [42] = 0.008,
    [40] = 0.0095,
    [38] = 0.0125,
    [36] = 0.016,
    [34] = 0.019,
    [32] = 0.025,
    [30] = 0.03,
    [28] = 0.04,
    [26] = 0.05,
    [24] = 0.06,
    [22] = 0.08,
    [20] = 0.10,
    [18] = 0.12,
    [16] = 0.16,
    [15] = 0.18
}

local vals_gaussian = {
    [60] = 0.0012,
    [58] = 0.0015,
    [56] = 0.0019,
    [54] = 0.0024,
    [52] = 0.003,
    [50] = 0.0038,
    [48] = 0.0045,
    [46] = 0.006,
    [44] = 0.0075,
    [42] = 0.0095,
    [40] = 0.0115,
    [38] = 0.015,
    [36] = 0.019,
    [34] = 0.0235,
    [32] = 0.03,
    [30] = 0.037,
    [28] = 0.045,
    [26] = 0.055,
    [24] = 0.07,
    [22] = 0.09,
    [20] = 0.11,
    [18] = 0.14,
    [16] = 0.18,
    [15] = 0.20
}

local n = 300
local p = assert(arg[1])
local w = assert(arg[2])

local vals = p == 'uniform' and vals_uniform or vals_gaussian

local pvals = {}
for db, level in pairs(vals) do table.insert(pvals, {db, level}) end
table.sort(pvals, function(a,b) return a[1] > b[1] end)

local sf = string.format

for i, v in ipairs(pvals) do
    local db, level = v[1], v[2]
    local inp, out  = sf('data/%s/%d/orig', p, w), sf('data/%s/%d/%d', p, w, db)
    os.execute('mkdir ' .. out)
    local cmd       = sf('./noise_add %s %s < %s > %s/', level, db, inp, out)

    for i = 1, n do
        local ncmd = cmd .. i
        print(ncmd)
        os.execute(ncmd)
    end
end
