#! /usr/bin/env lua

--[[
    Executes a program n times and calculates the output mean and
    sample standard deviation.
    
    Usage: ./test.lua program profile wave_len db
--]]

local function calc_std(tbl)
    if #tbl == 1 then return tbl[1], 0 end

    local total = 0
    
    for i, j in ipairs(tbl) do
        total = total + j
    end
    
    local mean = total / #tbl
    local sum  = 0
    
    for i, j in ipairs(tbl) do
        local tmp = mean - j
        sum = sum + tmp * tmp
    end
    
    local std = math.sqrt(sum / (#tbl - 1) )
    return mean, std
end

for i = 1, 4 do
    if not arg[i] then
        print('Usage: ' .. arg[0] .. ' program profile wave_len db [num]')
        os.exit(0)
    end
end

local prog     = arg[1]
local profile  = arg[2]
local wave_len = arg[3]
local db       = arg[4]
local n        = tonumber(arg[5]) or 300

local cmd  = string.format('./%s < data/%s/%s/%s/', prog, profile, wave_len, db)
local res  = {}

for i = 1, n do
    local ncmd = cmd .. i
    local f = io.popen(ncmd)
    local w = f:read('*n')
    table.insert(res, w)
    f:close()
end

local mean, std = calc_std(res)
print( string.format('%.12f %.12f', mean, std) )
